import { AbstractControlOptions, AsyncValidatorFn, FormBuilder, FormGroup, ValidatorFn } from '@angular/forms';
import { ClassTransformOptions } from 'class-transformer';
import { ClassType } from 'class-transformer/ClassTransformer';
import { ValidatorOptions } from 'class-validator-multi-lang';
import 'reflect-metadata';
import { BehaviorSubject, Subject, Subscription } from 'rxjs';
import { Dictionary } from '../types/dictionary';
import { FormModel } from '../types/form-model';
import { ShortValidationErrors } from '../types/short-validation-errors';
import { DynamicFormBuilder } from './dynamic-form-builder';
import { DynamicFormGroupConfig } from '../types/dynamic-form-group-config';
export declare class DynamicFormGroup<TModel> extends FormGroup {
    factoryModel: ClassType<TModel>;
    fields?: FormModel<TModel> | undefined;
    private _validatorOrOpts?;
    private _asyncValidator?;
    private readonly options?;
    nativeValidateErrors: BehaviorSubject<Dictionary<any>>;
    customValidateErrors: BehaviorSubject<ShortValidationErrors>;
    formErrors: ShortValidationErrors;
    formFields: Dictionary;
    objectChange: Subject<unknown>;
    valueChangesSubscription: Subscription;
    dynamicFormBuilder: DynamicFormBuilder;
    originalFormBuilder: FormBuilder;
    private _object;
    private _externalErrors;
    private _validatorOptions;
    private _classTransformOptions;
    private _validateSubscription;
    private _validateAllFormFields;
    constructor(factoryModel: ClassType<TModel>, fields?: FormModel<TModel> | undefined, _validatorOrOpts?: ValidatorFn | ValidatorFn[] | AbstractControlOptions | null | undefined, _asyncValidator?: AsyncValidatorFn | AsyncValidatorFn[] | null | undefined, options?: DynamicFormGroupConfig | undefined);
    subscribeToValueChanges(externalErrors?: ShortValidationErrors, validatorOptions?: ValidatorOptions): void;
    set externalErrors(externalErrors: ShortValidationErrors);
    get externalErrors(): ShortValidationErrors;
    set classTransformOptions(classTransformOptions: ClassTransformOptions);
    get classTransformOptions(): ClassTransformOptions;
    set validatorOptions(validatorOptions: ValidatorOptions);
    get validatorOptions(): ValidatorOptions;
    set object(object: TModel);
    get object(): TModel;
    set json(jsonData: any);
    get json(): any;
    validateStream(externalErrors?: ShortValidationErrors, validatorOptions?: ValidatorOptions): import("rxjs").Observable<[{
        [key: string]: string;
    }, {
        [key: string]: string;
    } | undefined]>;
    validateAsync(externalErrors?: ShortValidationErrors, validatorOptions?: ValidatorOptions): Promise<[{
        [key: string]: string;
    }, {
        [key: string]: string;
    } | undefined]>;
    validate(externalErrors?: ShortValidationErrors, validatorOptions?: ValidatorOptions): void;
    setCustomErrors(allErrors: any, force?: boolean): void;
    private collectErrors;
    validateAllFormFields(): void;
    resetValidateAllFormFields(): void;
    classToClass<TClassModel>(object: TClassModel): any;
    plainToClass<TClassModel, Object>(cls: ClassType<TClassModel>, plain: Object): any;
    classToPlain<TClassModel>(object: TClassModel): any;
    /**
     * @deprecated please use sync method setExternalErrors(errors)
     */
    setExternalErrorsAsync(externalErrors: ShortValidationErrors): Promise<void>;
    setExternalErrors(externalErrors: ShortValidationErrors): void;
    getExternalErrors(): ShortValidationErrors;
    /**
     * @deprecated please use sync method setExternalErrors({})
     */
    clearExternalErrorsAsync(): Promise<void>;
    clearExternalErrors(): void;
    setValidatorOptions(validatorOptions?: ValidatorOptions): void;
    getValidatorOptions(): ValidatorOptions;
    private onlyFields;
    private markAsInvalidForExternalErrors;
    /**
     * Recursively gets all values from the form controls and all sub form group and array controls and returns it as
     * an object
     */
    private getObject;
    /**
     * Sets the value of every control on the form and recursively sets the values of the controls
     * on all sub form groups
     *
     * @param object the data to assign to all controls of the form group and sub groups
     */
    private setObject;
    private getJSON;
    private setJSON;
}
export declare function getClassValidators<TModel>(factoryModel: ClassType<TModel>, fields?: Dictionary, validatorOptions?: ValidatorOptions): {};
